package #
Locale::Codes::LangExt_Retired;

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'deprecate_codes' is run.
#    Generated on: Tue Sep  2 11:08:53 EDT 2025

use strict;
require 5.006;
use warnings;
use utf8;

our($VERSION);
$VERSION='3.85';

$Locale::Codes::Retired{'langext'}{'alpha'}{'code'} = {
   q(ajp) => q(South Levantine Arabic),
   q(bbz) => q(Babalia Creole Arabic),
   q(lsg) => q(Lyons Sign Language),
   q(rsi) => q(Rennellese Sign Language),
   q(yds) => q(Yiddish Sign Language),
};

$Locale::Codes::Retired{'langext'}{'alpha'}{'name'} = {
   q(australian sign language) => [ q(asf), q(Australian Sign Language) ],
   q(babalia creole arabic) => [ q(bbz), q(Babalia Creole Arabic) ],
   q(hawai'i pidgin sign language) => [ q(hps), q(Hawai'i Pidgin Sign Language) ],
   q(lyons sign language) => [ q(lsg), q(Lyons Sign Language) ],
   q(north levantine arabic) => [ q(apc), q(North Levantine Arabic) ],
   q(persian sign language) => [ q(psc), q(Persian Sign Language) ],
   q(rennellese sign language) => [ q(rsi), q(Rennellese Sign Language) ],
   q(south levantine arabic) => [ q(ajp), q(South Levantine Arabic) ],
   q(yiddish sign language) => [ q(yds), q(Yiddish Sign Language) ],
};


1;
