package #
Locale::Codes::Currency_Retired;

# This file was automatically generated.  Any changes to this file will
# be lost the next time 'deprecate_codes' is run.
#    Generated on: Tue Sep  2 11:08:53 EDT 2025

use strict;
require 5.006;
use warnings;
use utf8;

our($VERSION);
$VERSION='3.85';

$Locale::Codes::Retired{'currency'}{'alpha'}{'code'} = {
   q(ADP) => q(Andorran Peseta),
   q(AFA) => q(Afghani),
   q(ANG) => q(Netherlands Antillean Guilder),
   q(AON) => q(New Kwanza),
   q(AOR) => q(Kwanza Reajustado),
   q(ATS) => q(Schilling),
   q(AZM) => q(Azerbaijanian Manat),
   q(BEF) => q(Belgian Franc),
   q(BGL) => q(Lev),
   q(BYB) => q(Belarussian Ruble),
   q(CUC) => q(Peso Convertible),
   q(CYP) => q(Cyprus Pound),
   q(DEM) => q(German Mark),
   q(ECS) => q(Sucre),
   q(ECV) => q(Unidad de Valor Constante (UVC)),
   q(EEK) => q(Kroon),
   q(ESP) => q(Spanish Peseta),
   q(FIM) => q(Markka),
   q(FRF) => q(French Franc),
   q(GHC) => q(Cedi),
   q(GRD) => q(Drachma),
   q(GWP) => q(Guinea-Bissau Peso),
   q(HRK) => q(Kuna),
   q(IEP) => q(Irish Pound),
   q(ITL) => q(Italian Lira),
   q(LTL) => q(Lithuanian Litas),
   q(LUF) => q(Luxembourg Franc),
   q(LVL) => q(Latvian Lats),
   q(MGF) => q(Malagasy Franc),
   q(MRO) => q(Ouguiya),
   q(MTL) => q(Maltese Lira),
   q(MZM) => q(Metical),
   q(NLG) => q(Netherlands Guilder),
   q(PTE) => q(Portuguese Escudo),
   q(ROL) => q(Leu),
   q(RUR) => q(Russian Ruble),
   q(SDD) => q(Sudanese Dinar),
   q(SHP) => q(Saint Helena Pound),
   q(SIT) => q(Tolar),
   q(SKK) => q(Slovak Koruna),
   q(SRG) => q(Surinam Guilder),
   q(STD) => q(Dobra),
   q(TJR) => q(Tajik Ruble),
   q(TMM) => q(Manat),
   q(TPE) => q(Timor Escudo),
   q(TRL) => q(Turkish Lira),
   q(UAK) => q(Karbovanets),
   q(USS) => q(US Dollar (Same day)),
   q(VEB) => q(Bolivar),
   q(VEF) => q(Bolivar),
   q(XB5) => q(European Unit of Account 17),
   q(XEU) => q(ECU (until 1998-12-31)),
   q(XFO) => q(Gold-Franc),
   q(XFU) => q(UIC-Franc),
   q(YUM) => q(New Dinar),
   q(ZAL) => q(Financial Rand),
   q(ZRN) => q(New Zaire),
   q(ZWD) => q(Zimbabwe Dollar),
   q(ZWL) => q(Zimbabwe Dollar),
};

$Locale::Codes::Retired{'currency'}{'num'}{'code'} = {
   q(191) => q(Kuna),
   q(428) => q(Latvian Lats),
   q(440) => q(Lithuanian Litas),
   q(478) => q(Ouguiya),
   q(654) => q(Saint Helena Pound),
   q(678) => q(Dobra),
   q(931) => q(Peso Convertible),
   q(932) => q(Zimbabwe Dollar),
   q(937) => q(Bolivar),
   q(998) => q(US Dollar (Same day)),
};

$Locale::Codes::Retired{'currency'}{'alpha'}{'name'} = {
   q(andorran peseta) => [ q(ADP), q(Andorran Peseta) ],
   q(aruban guilder) => [ q(AWG), q(Aruban Guilder) ],
   q(azerbaijanian manat) => [ q(AZN), q(Azerbaijanian Manat) ],
   q(belarussian ruble) => [ q(BYR), q(Belarussian Ruble) ],
   q(belgian franc) => [ q(BEF), q(Belgian Franc) ],
   q(bermudian dollar (customarily known as bermuda dollar)) => [ q(BMD), q(Bermudian Dollar (customarily known as Bermuda Dollar)) ],
   q(bolivar) => [ q(VEF), q(Bolivar) ],
   q(bolivar fuerte) => [ q(VEF), q(Bolivar Fuerte) ],
   q(bond markets units european composite unit (eurco)) => [ q(XBA), q(Bond Markets Units European Composite Unit (EURCO)) ],
   q(candian dollar) => [ q(CAD), q(Candian Dollar) ],
   q(cape verde escudo) => [ q(CVE), q(Cape Verde Escudo) ],
   q(cedi) => [ q(GHS), q(Cedi) ],
   q(comoro franc) => [ q(KMF), q(Comoro Franc) ],
   q(convertible marks) => [ q(BAM), q(Convertible Marks) ],
   q(croatian kuna) => [ q(HRK), q(Croatian Kuna) ],
   q(cyprus pound) => [ q(CYP), q(Cyprus Pound) ],
   q(dinar) => [ q(BHD), q(Dinar) ],
   q(drachma) => [ q(GRD), q(Drachma) ],
   q(ecu (until 1998-12-31)) => [ q(XEU), q(ECU (until 1998-12-31)) ],
   q(european composite unit) => [ q(XBA), q(European Composite Unit) ],
   q(european monetary unit) => [ q(XBB), q(European Monetary Unit) ],
   q(european monetary unit (e.m.u.-6)) => [ q(XBB), q(European Monetary Unit (E.M.U.-6)) ],
   q(european unit of account 17) => [ q(XB5), q(European Unit of Account 17) ],
   q(european unit of account 17(e.u.a.-17)) => [ q(XBD), q(European Unit of Account 17(E.U.A.-17)) ],
   q(european unit of account 9) => [ q(XBC), q(European Unit of Account 9) ],
   q(european unit of account 9(e.u.a.-9)) => [ q(XBC), q(European Unit of Account 9(E.U.A.-9)) ],
   q(financial rand) => [ q(ZAL), q(Financial Rand) ],
   q(franc congolais) => [ q(CDF), q(Franc Congolais) ],
   q(french franc) => [ q(FRF), q(French Franc) ],
   q(german mark) => [ q(DEM), q(German Mark) ],
   q(gold-franc) => [ q(XFO), q(Gold-Franc) ],
   q(guinea franc) => [ q(GNF), q(Guinea Franc) ],
   q(guinea-bissau peso) => [ q(GWP), q(Guinea-Bissau Peso) ],
   q(irish pound) => [ q(IEP), q(Irish Pound) ],
   q(italian lira) => [ q(ITL), q(Italian Lira) ],
   q(karbovanets) => [ q(UAK), q(Karbovanets) ],
   q(kip) => [ q(LAK), q(Kip) ],
   q(kroon) => [ q(EEK), q(Kroon) ],
   q(kuna) => [ q(HRK), q(Kuna) ],
   q(kwacha) => [ q(MWK), q(Kwacha) ],
   q(kwanza reajustado) => [ q(AOR), q(Kwanza Reajustado) ],
   q(latvian lats) => [ q(LVL), q(Latvian Lats) ],
   q(leu) => [ q(RON), q(Leu) ],
   q(lev) => [ q(BGL), q(Lev) ],
   q(lithuanian litas) => [ q(LTL), q(Lithuanian Litas) ],
   q(luxembourg franc) => [ q(LUF), q(Luxembourg Franc) ],
   q(malagasy franc) => [ q(MGF), q(Malagasy Franc) ],
   q(maltese lira) => [ q(MTL), q(Maltese Lira) ],
   q(manat) => [ q(TMT), q(Manat) ],
   q(markka) => [ q(FIM), q(Markka) ],
   q(metical) => [ q(MZN), q(Metical) ],
   q(mexican nuevo peso) => [ q(MXN), q(Mexican Nuevo Peso) ],
   q(netherlands antillean guilder) => [ q(ANG), q(Netherlands Antillean Guilder) ],
   q(netherlands antillian guilder) => [ q(ANG), q(Netherlands Antillian Guilder) ],
   q(netherlands guilder) => [ q(NLG), q(Netherlands Guilder) ],
   q(new dinar) => [ q(YUM), q(New Dinar) ],
   q(new kwanza) => [ q(AON), q(New Kwanza) ],
   q(new leu) => [ q(RON), q(New Leu) ],
   q(new manat) => [ q(TMT), q(New Manat) ],
   q(new romanian leu) => [ q(RON), q(New Romanian Leu) ],
   q(new zaire) => [ q(ZRN), q(New Zaire) ],
   q(nuevo sol) => [ q(PEN), q(Nuevo Sol) ],
   q(peso convertible) => [ q(CUC), q(Peso Convertible) ],
   q(philippine peso) => [ q(PHP), q(Philippine Peso) ],
   q(philippine piso) => [ q(PHP), q(Philippine Piso) ],
   q(portuguese escudo) => [ q(PTE), q(Portuguese Escudo) ],
   q(saint helena pound) => [ q(SHP), q(Saint Helena Pound) ],
   q(schilling) => [ q(ATS), q(Schilling) ],
   q(sdr) => [ q(XDR), q(SDR) ],
   q(shekel) => [ q(ILS), q(Shekel) ],
   q(slovak koruna) => [ q(SKK), q(Slovak Koruna) ],
   q(spanish peseta) => [ q(ESP), q(Spanish Peseta) ],
   q(st. helena pound) => [ q(SHP), q(St. Helena Pound) ],
   q(sudanese dinar) => [ q(SDD), q(Sudanese Dinar) ],
   q(surinam guilder) => [ q(SRG), q(Surinam Guilder) ],
   q(tajik ruble) => [ q(TJR), q(Tajik Ruble) ],
   q(timor escudo) => [ q(TPE), q(Timor Escudo) ],
   q(tolar) => [ q(SIT), q(Tolar) ],
   q(tunisian dollar) => [ q(TND), q(Tunisian Dollar) ],
   q(uic-franc) => [ q(XFU), q(UIC-Franc) ],
   q(unidad de valor constante (uvc)) => [ q(ECV), q(Unidad de Valor Constante (UVC)) ],
   q(unidades de fomento) => [ q(CLF), q(Unidades de fomento) ],
   q(unidades de formento) => [ q(CLF), q(Unidades de Formento) ],
   q(uruguay peso en unidades indexadas) => [ q(UYI), q(Uruguay Peso en Unidades Indexadas) ],
   q(uruguay peso en unidades indexadas (uruiurui)) => [ q(UYI), q(Uruguay Peso en Unidades Indexadas (URUIURUI)) ],
   q(us dollar (same day)) => [ q(USS), q(US Dollar (Same day)) ],
   q(zimbabwe dollar) => [ q(ZWL), q(Zimbabwe Dollar) ],
};

$Locale::Codes::Retired{'currency'}{'num'}{'name'} = {
   q(azerbaijanian manat) => [ q(944), q(Azerbaijanian Manat) ],
   q(belarussian ruble) => [ q(974), q(Belarussian Ruble) ],
   q(bolivar) => [ q(937), q(Bolivar) ],
   q(bolivar fuerte) => [ q(937), q(Bolivar Fuerte) ],
   q(cape verde escudo) => [ q(132), q(Cape Verde Escudo) ],
   q(cedi) => [ q(936), q(Cedi) ],
   q(comoro franc) => [ q(174), q(Comoro Franc) ],
   q(croatian kuna) => [ q(191), q(Croatian Kuna) ],
   q(guinea franc) => [ q(324), q(Guinea Franc) ],
   q(kip) => [ q(418), q(Kip) ],
   q(kuna) => [ q(191), q(Kuna) ],
   q(kwacha) => [ q(454), q(Kwacha) ],
   q(latvian lats) => [ q(428), q(Latvian Lats) ],
   q(leu) => [ q(946), q(Leu) ],
   q(lithuanian litas) => [ q(440), q(Lithuanian Litas) ],
   q(metical) => [ q(943), q(Metical) ],
   q(netherlands antillean guilder) => [ q(532), q(Netherlands Antillean Guilder) ],
   q(new manat) => [ q(934), q(New Manat) ],
   q(new romanian leu) => [ q(946), q(New Romanian Leu) ],
   q(nuevo sol) => [ q(604), q(Nuevo Sol) ],
   q(peso convertible) => [ q(931), q(Peso Convertible) ],
   q(philippine peso) => [ q(608), q(Philippine Peso) ],
   q(philippine piso) => [ q(608), q(Philippine Piso) ],
   q(saint helena pound) => [ q(654), q(Saint Helena Pound) ],
   q(unidades de fomento) => [ q(990), q(Unidades de fomento) ],
   q(uruguay peso en unidades indexadas (uruiurui)) => [ q(940), q(Uruguay Peso en Unidades Indexadas (URUIURUI)) ],
   q(us dollar (same day)) => [ q(998), q(US Dollar (Same day)) ],
   q(zimbabwe dollar) => [ q(932), q(Zimbabwe Dollar) ],
};


1;
